from resa_padel.gestion_sports.payload_builders import (
    GestionSportsBookingPayloadBuilder,
    GestionSportsLoginPayloadBuilder,
    GestionSportsUsersBookingsPayloadBuilder,
)
from tests.fixtures import a_booking_filter, a_club, a_user


def test_login_payload_should_be_built(a_user, a_club):
    """
    Test that the login payload is filled with the right template
    and filled accordingly

    :param a_user: the user information fixture
    :param a_club: the club information fixture
    """
    payload_builder = GestionSportsLoginPayloadBuilder()
    login_payload = payload_builder.user(a_user).club(a_club).build()

    expected_payload = (
        f"ajax=connexionUser&id_club={a_club.id}&email={a_user.login}&form_ajax=1"
        f"&pass={a_user.password}&compte=user&playeridonesignal=0"
        f"&identifiant=identifiant&externCo=true"
    )

    assert login_payload == expected_payload


def test_booking_payload_should_be_built(a_booking_filter):
    """
    Test that the booking payload is filled with the right template
    and filled accordingly

    :param a_booking_filter: the booking information fixture
    """
    booking_builder = GestionSportsBookingPayloadBuilder()
    booking_payload = (
        booking_builder.booking_filter(a_booking_filter).court_id(4).build()
    )

    expected_date = a_booking_filter.date.date().strftime("%d/%m/%Y")
    expected_time = a_booking_filter.date.time().strftime("%H:%M")
    expected_payload = (
        f"ajax=addResa&date={expected_date}"
        f"&hour={expected_time}&duration=90&partners=null|null|null"
        f"&paiement=facultatif&idSport={a_booking_filter.sport_id}"
        f"&creaPartie=false&idCourt=4&pay=false&token=undefined&totalPrice=44"
        f"&saveCard=0&foodNumber=0"
    )

    assert booking_payload == expected_payload


def test_users_bookings_payload_should_be_built():
    builder = GestionSportsUsersBookingsPayloadBuilder()
    builder.hash("super_hash")
    expected_payload = "ajax=loadResa&hash=super_hash"

    actual_payload = builder.build()

    assert actual_payload == expected_payload
